@@ -467,7 +467,7 @@ def MulityPageExportFileToExcel(data:list,FlieName="data.xlsx"):
     Index=0
     for i in data:
         for j in  i :
-            sheet1.write(Index, 0, data[i][j])
+            sheet1.write(Index, 0, j)
             Index+=1
     f.save(FlieName)
 
